define(["require", "exports", "./enum-type"], function (require, exports, enum_type_1) {
    "use strict";
    function originRulesAnalyse(originRules) {
        var realRules = {};
        for (var p in originRules) {
            var ruleStr = originRules[p];
            updateRule(realRules, p, ruleStr);
        }
        return realRules;
    }
    exports.originRulesAnalyse = originRulesAnalyse;
    function updateRule(rules, propName, propValue) {
        var ruleStringList = propValue.split(/\s*\|\s*/), selectorSplit = propName.split(/\s*:\s*/), field = selectorSplit[0];
        if (rules[field] === undefined) {
            rules[field] = [];
        }
        var ruleItem = rules[field];
        for (var i = 0, len = ruleStringList.length; i < len; i++) {
            var ruleStringItem = ruleStringList[i].split(/\s*:\s*/), ruleParams = void 0, methodName = ruleStringItem.splice(0, 1)[0].replace(/^\s+|\s+$/g, ''), isReverse = false;
            if (ruleStringItem.length > 0) {
                ruleParams = ruleStringItem.map(function (item) {
                    var type;
                    if (/^\s*['"]|['"]\s*$/.test(item) || /^-?\d+(?:\.\d+)?$/.test(item)) {
                        type = enum_type_1.ParamType.VALUE;
                    }
                    else {
                        type = enum_type_1.ParamType.PROPERTY;
                    }
                    return {
                        type: type,
                        value: item.replace(/^\s+|\s+$/g, '').replace(/^['"]|['"]$/g, '')
                    };
                });
            }
            if (methodName.indexOf('!') !== -1) {
                isReverse = true;
                methodName = methodName.substr(1);
            }
            ruleItem.push({
                method: methodName,
                params: ruleParams,
                reverse: isReverse
            });
        }
    }
});
//# sourceMappingURL=origin-rules-analyse.js.map